package com.persagy.apm.model;

import org.mapstruct.*;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;
import com.persagy.apm.model.vo.*;
import com.persagy.apm.model.dto.*;

import java.util.List;

/**
 * 计算方式(CalculateMethod) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-09-07 18:12:05
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertCalculateMethodTool {

    ConvertCalculateMethodTool INSTANCE = Mappers.getMapper(ConvertCalculateMethodTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param calculateMethod do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:05
     */
    CalculateMethodItemVO convert2ResponseItemDTO(CalculateMethod calculateMethod);

    /**
     * do转换为ResponseListItemVO
     *
     * @param calculateMethod do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:05
     */
    CalculateMethodListItemVO convert2ResponseListItemDTO(CalculateMethod calculateMethod);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param calculateMethodList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-09-07 18:12:05
     */
    List<CalculateMethodListItemVO> convert2List(List<CalculateMethod> calculateMethodList);

    /**
     * addDTO转换为do
     *
     * @param addCalculateMethodDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:05
     */
    CalculateMethod convertAddDto2Entity(AddCalculateMethodDTO addCalculateMethodDTO);

    /**
     * updateDTO转换为实体
     *
     * @param calculateMethod          更新前的do对象
     * @param updateCalculateMethodDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:05
     */
    CalculateMethod convertUpdateDto2Entity(@MappingTarget CalculateMethod calculateMethod, UpdateCalculateMethodDTO updateCalculateMethodDTO);
}

