package com.persagy.apm.model;

import org.mapstruct.*;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;
import com.persagy.apm.model.vo.*;
import com.persagy.apm.model.dto.*;

import java.util.List;

/**
 * 监测指标(MonitorIndicator) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-09-07 18:12:07
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertMonitorIndicatorTool {

    ConvertMonitorIndicatorTool INSTANCE = Mappers.getMapper(ConvertMonitorIndicatorTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param monitorIndicator do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:07
     */
    MonitorIndicatorItemVO convert2ResponseItemDTO(MonitorIndicator monitorIndicator);

    /**
     * do转换为ResponseListItemVO
     *
     * @param monitorIndicator do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:07
     */
    MonitorIndicatorListItemVO convert2ResponseListItemDTO(MonitorIndicator monitorIndicator);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param monitorIndicatorList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-09-07 18:12:07
     */
    List<MonitorIndicatorListItemVO> convert2List(List<MonitorIndicator> monitorIndicatorList);

    /**
     * addDTO转换为do
     *
     * @param addMonitorIndicatorDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:07
     */
    MonitorIndicator convertAddDto2Entity(AddMonitorIndicatorDTO addMonitorIndicatorDTO);

    /**
     * updateDTO转换为实体
     *
     * @param monitorIndicator          更新前的do对象
     * @param updateMonitorIndicatorDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:07
     */
    MonitorIndicator convertUpdateDto2Entity(@MappingTarget MonitorIndicator monitorIndicator, UpdateMonitorIndicatorDTO updateMonitorIndicatorDTO);
}

