package com.persagy.apm.model;

import org.mapstruct.*;
import org.mapstruct.MappingTarget;
import org.mapstruct.factory.Mappers;
import com.persagy.apm.model.vo.*;
import com.persagy.apm.model.dto.*;

import java.util.List;

/**
 * 项目报警规则(ProjectAlarmRule) dto、vo、do转换工具类
 *
 * @author lixing
 * @version V1.0 2021-09-07 18:12:08
 */
@Mapper(nullValueMappingStrategy = NullValueMappingStrategy.RETURN_DEFAULT,
        nullValueCheckStrategy = NullValueCheckStrategy.ALWAYS)
public interface ConvertProjectAlarmRuleTool {

    ConvertProjectAlarmRuleTool INSTANCE = Mappers.getMapper(ConvertProjectAlarmRuleTool.class);

    /**
     * do转换为ResponseItemVO
     *
     * @param projectAlarmRule do对象
     * @return ResponseItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:08
     */
    ProjectAlarmRuleItemVO convert2ResponseItemDTO(ProjectAlarmRule projectAlarmRule);

    /**
     * do转换为ResponseListItemVO
     *
     * @param projectAlarmRule do对象
     * @return ResponseListItemVO
     * @author lixing
     * @version V1.0 2021-09-07 18:12:08
     */
    ProjectAlarmRuleListItemVO convert2ResponseListItemDTO(ProjectAlarmRule projectAlarmRule);

    /**
     * do列表转换为ResponseListItemVO列表
     *
     * @param projectAlarmRuleList do列表
     * @return ResponseListItemVO列表
     * @author lixing
     * @version V1.0 2021-09-07 18:12:08
     */
    List<ProjectAlarmRuleListItemVO> convert2List(List<ProjectAlarmRule> projectAlarmRuleList);

    /**
     * addDTO转换为do
     *
     * @param addProjectAlarmRuleDTO addDTO
     * @return 要创建的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:08
     */
    ProjectAlarmRule convertAddDto2Entity(AddProjectAlarmRuleDTO addProjectAlarmRuleDTO);

    /**
     * updateDTO转换为实体
     *
     * @param projectAlarmRule          更新前的do对象
     * @param updateProjectAlarmRuleDTO updateDTO
     * @return 更新后的do对象
     * @author lixing
     * @version V1.0 2021-09-07 18:12:08
     */
    ProjectAlarmRule convertUpdateDto2Entity(@MappingTarget ProjectAlarmRule projectAlarmRule, UpdateProjectAlarmRuleDTO updateProjectAlarmRuleDTO);
}

